# Security Policy

## Supported Versions

These versions of the project are
currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 1.0.0   | :white_check_mark: |

## Reporting a Vulnerability

Create a post in the community page and I'll get around to fixing it; the more major the vulnerability the faster I'll get to it.
